@@ -8,7 +8,6 @@ def common(**kwargs):
     base = kwargs['base']
 
     DEBUG = True
-    TEMPLATE_DEBUG = DEBUG
 
     ADMINS = []
     MANAGERS = ADMINS
@@ -89,6 +88,7 @@ def common(**kwargs):
         },
     ]
 
+    # Django 1.x
     MIDDLEWARE_CLASSES = [
         'django_statsd.middleware.GraphiteRequestTimingMiddleware',
         'django_statsd.middleware.GraphiteMiddleware',
@@ -96,11 +96,12 @@ def common(**kwargs):
         'django.contrib.sessions.middleware.SessionMiddleware',
         'django.contrib.auth.middleware.AuthenticationMiddleware',
         'django.contrib.flatpages.middleware.FlatpageFallbackMiddleware',
-        'debug_toolbar.middleware.DebugToolbarMiddleware',
         'django.contrib.messages.middleware.MessageMiddleware',
         'waffle.middleware.WaffleMiddleware',
         'impersonate.middleware.ImpersonateMiddleware',
     ]
+    # DJANGO 2.X
+    MIDDLEWARE = MIDDLEWARE_CLASSES
 
     ROOT_URLCONF = project + '.urls'
 
@@ -115,7 +116,6 @@ def common(**kwargs):
         'django.contrib.admin',
         'django_statsd',
         'smoketest',
-        'debug_toolbar',
         'django_jenkins',
         'gunicorn',
         'compressor',
@@ -126,15 +126,6 @@ def common(**kwargs):
     ]
 
     INTERNAL_IPS = ['127.0.0.1']
-    DEBUG_TOOLBAR_PANELS = [
-        'debug_toolbar.panels.version.VersionDebugPanel',
-        'debug_toolbar.panels.timer.TimerDebugPanel',
-        'debug_toolbar.panels.headers.HeaderDebugPanel',
-        'debug_toolbar.panels.request_vars.RequestVarsDebugPanel',
-        'debug_toolbar.panels.template.TemplateDebugPanel',
-        'debug_toolbar.panels.sql.SQLDebugPanel',
-        'debug_toolbar.panels.signals.SignalDebugPanel',
-    ]
 
     STATSD_CLIENT = 'statsd.client'
     STATSD_PREFIX = project
@@ -168,9 +159,8 @@ def common(**kwargs):
     WIND_STAFF_MAPPER_GROUPS = ['tlc.cunix.local:columbia.edu']
     WIND_SUPERUSER_MAPPER_GROUPS = [
         'amm8',
-        'anp8',
-        'jb2410',
         'mar227',
+        'nb2413',
         'njn2118',
         'sld2131',
         'zm4',
@@ -196,6 +186,6 @@ def common(**kwargs):
         'disable_existing_loggers': True,
     }
 
-    GRAPHITE_BASE = "https://nanny-render.cul.columbia.edu/render/"
+    GRAPHITE_BASE = "https://graphite.ctl.columbia.edu/render/"
 
     return locals()
